;; Generated package description from dired-preview.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "dired-preview" "0.4.0" "Automatically preview file at point in Dired" '((emacs "28.1")) :commit "6caf3b15802ddcbbb89ee7278e714c3158f76d83" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :keywords '("files" "convenience") :url "https://github.com/protesilaos/dired-preview")
